@@ -497,4 +497,4 @@ class ResourceSet(object):
             self._store.remove((self._subject._id, self._predicate, obj))
 
     def any(self):
-        list(self._store.objects(self._subject._id, self._predicate))[0]
+        return list(self._store.objects(self._subject._id, self._predicate))[0]
